<?php
/**
 * $Horde: jonah/dispatcher.php,v 1.4 2008-09-04 03:00:32 chuck Exp $
 *
 * Copyright 2008 The Horde Project (http://www.horde.org/)
 *
 * See the enclosed file LICENSE for license information (BSD). If you did
 * did not receive this file, see http://cvs.horde.org/co.php/jonah/LICENSE.
 *
 * @author Ben Klang <ben@alkaloid.net>
 */
$session_control = 'readonly';
@define('AUTH_HANDLER', true);
@define('JONAH_BASE', dirname(__FILE__));
require_once JONAH_BASE . '/lib/base.php';
require_once JONAH_BASE . '/lib/News.php';
require JONAH_BASE . '/config/templates.php';

require_once 'Horde/Date.php';

require_once 'Horde/Routes/Utils.php';
require_once 'Horde/Routes/Route.php';
require_once 'Horde/Routes/Exception.php';
require_once 'Horde/Routes/Mapper.php';

$m = new Horde_Routes_Mapper();
$m->connect('Admin', '/admin/:section/:page', array(
     'controller' => 'admin',
     'section' => '',
     'page' => '',
));

$m->connect('Default', '/:feed/:filter/:value', array(
    'controller' => 'feed',
    'feed' => '',
    'filter' => '',
    'value' => ''
));

// Valid filter names are "author" "tag" and "date"

/* Grab, and hopefully match, the URL */
$url = $_SERVER['PATH_INFO'];
parse_str($_SERVER['QUERY_STRING'], $args);
Util::dispelMagicQuotes($args);

$criteria = array();
$result = $m->match($url);
if (isset($result['controller']) && $result['controller'] == 'admin') {
    // Insert admin controllers here.
} elseif (isset($result['feed'])) {
    // Default settings
    $defaults = array(
        'format' => 'html',
        'feed' => $result['feed'],
    );

    // Check for the format specification
    if ($pos = strrpos($result['feed'], '.')) {
        $criteria['feed'] = substr($result['feed'], 0, $pos);
        $criteria['format'] = substr($result['feed'], $pos + 1);
    }

    if (!empty($result['filter'])) {
        switch ($result['filter']) {
        case 'author':
            $criteria['author'] = $result['value'];
            break;

        case 'date':
            if (preg_match('/\d{4}-\d{1,2}/', $result['value'])) {
                list($year, $month) = explode('-', $result['value']);
                $criteria['updated-min'] = new Horde_Date(array(
                                                   'month' => $month,
                                                   'year' => $year));
                // Set the end date to the end of the requested month
                $criteria['updated-max'] = new Horde_Date(array(
                                                   'month' => ++$month,
                                                   'year' => $year));
                $criteria['updated-max']->sec--;
                $criteria['updated-max']->correct();
                break;
            }

        case 'tag':
            $criteria['tags'] = array($result['value']);
            break;
        }
    }

    if (isset($args['tags'])) {
        if (strpos($args['tags'], '|') !== false) {
            // We have an OR list of tags
            $criteria['tags'] = explode('|', $args['tags']);
        } elseif (strpos($args['tags'], ',') !== false) {
            // We have an AND list of tags
            $criteria['alltags'] = explode(',', $args['tags']);
        } else {
            // Just a single tag
            $criteria['tags'] = array($args['tags']);
        }
    }
    unset($args['tags']);

    // These dates are expected to be in RFC 3339 format
    if (isset($args['updated-min'])) {
        $criteria['updated-min'] = new Horde_Date($args['updated-min']);
        unset($args['updated-min']);
    }
    if (isset($args['updated-max'])) {
        $criteria['updated-max'] = new Horde_Date($args['updated-max']);
        unset($args['updated-max']);
    }
    if (isset($args['published-min'])) {
        $criteria['published-min'] = new Horde_Date($args['published-min']);
        unset($args['published-min']);
    }
    if (isset($args['published-max'])) {
        $criteria['published-max'] = new Horde_Date($args['published-max']);
        unset($args['published-max']);
    }

    // Parse keyword search arguments
    $keywords = array();
    $notkeywords = array();
    if (isset($args['q'])) {
        $query = $args['q'];
       
        // Look for quoted strings
        while (($quotepos = strpos($query, '"')) !== false) {
            if ($quotepos !== 0) {
                $keywords = array_merge(explode(' ', substr($query, 0, $quotepos)), $keywords);
                $query = substr($query, $quotepos);
            }
            
            $keywords[] = substr($query, 1, strpos($query, '"', 1) - 1);
            $query = substr($query, 1);
            $query = substr($query, strpos($query, '"', 1) + 1);
        }

        // Split up any remaining text into keywords
        $keywords = array_merge(explode(' ', $query), $keywords);

        // Remove duplicates and empty values
        $keywords = array_flip($keywords);
        unset ($keywords['']);
        $keywords = array_flip($keywords);

        // We're done with 'q'.  Unset it to prevent it being copied into
        // $criteria below.
        unset($args['q']);

        foreach ($keywords as $index => $keyword) {
            if (substr($keyword, 0, 1) == '-') {
                $notkeywords[] = substr($keyword, 1);
                unset($keywords[$index]);
            }
        }

        // Save the criteria
        if (!empty($keywords)) {
            $criteria['keywords'] = $keywords;
        }
        if (!empty($notkeywords)) {
            $criteria['notkeywords'] = $notkeywords;
        }
    }
                

    // Preserve remaining args
    $criteria = array_merge($defaults, $args, $criteria);

    require dirname(__FILE__) . '/feed.php';
}
